ChiSquared

Struct ChiSquared 

pub struct ChiSquared { /* private fields */ }
Implements the Chi-squared distribution which is a special case of the Gamma distribution (referenced Here)

Examples

use statrs::distribution::{ChiSquared, Continuous};
use statrs::statistics::Distribution;
use approx::assert_abs_diff_eq;

let n = ChiSquared::new(3.0).unwrap();
assert_eq!(n.mean().unwrap(), 3.0);
assert_abs_diff_eq!(n.pdf(4.0), 0.107981933026376103901, epsilon = 1e-15);

Implementations

Source

impl ChiSquared

pub fn new(freedom: f64) -> Result<ChiSquared, GammaError>

Constructs a new chi-squared distribution with freedom degrees of freedom. This is equivalent to a Gamma distribution with a shape of freedom / 2.0 and a rate of 0.5.

Errors

Returns an error if freedom is NaN or less than or equal to 0.0

Examples
use statrs::distribution::ChiSquared;

let mut result = ChiSquared::new(3.0);
assert!(result.is_ok());

result = ChiSquared::new(0.0);
assert!(result.is_err());
pub fn freedom(&self) -> f64

Returns the degrees of freedom of the chi-squared distribution

Examples
use statrs::distribution::ChiSquared;

let n = ChiSquared::new(3.0).unwrap();
assert_eq!(n.freedom(), 3.0);
pub fn shape(&self) -> f64

Returns the shape of the underlying Gamma distribution

Examples
use statrs::distribution::ChiSquared;

let n = ChiSquared::new(3.0).unwrap();
assert_eq!(n.shape(), 3.0 / 2.0);
pub fn rate(&self) -> f64

Returns the rate of the underlying Gamma distribution

Examples
use statrs::distribution::ChiSquared;

let n = ChiSquared::new(3.0).unwrap();
assert_eq!(n.rate(), 0.5);